@@ -1,14 +1,9 @@
 package Tapper::Schema;
-# git description: v4.1.2-3-g816358e
+# git description: v4.1.3-56-ge003d52
 
-BEGIN {
-  $Tapper::Schema::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Database schemas for Tapper
-
+$Tapper::Schema::VERSION = '5.0.0';
 use warnings;
 use strict;
 
@@ -18,19 +13,29 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Schema - Tapper - Database schemas for Tapper
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
