@@ -1,11 +1,6 @@
 package Tapper::Schema::TestTools;
-BEGIN {
-  $Tapper::Schema::TestTools::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestTools::VERSION = '4.1.3';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestTools::VERSION = '5.0.0';
 # inspired by Test::Fixture::DBIC::Schema
 
 use strict;
@@ -17,13 +12,10 @@ BEGIN {
         $DBD::SQLite::sqlite_version; # fix "used only once" warning
 }
 
-use Tapper::Schema::TestrunDB;
-use Tapper::Schema::ReportsDB;
-
 use Tapper::Config;
+use Tapper::Schema::TestrunDB;
 
 my $testrundb_schema;
-my $reportsdb_schema;
 
 
 sub setup_db
@@ -37,10 +29,9 @@ sub setup_db
         my $dsn = $cfg->{dsn};
         my ($tmpfname) = $dsn =~ m,dbi:SQLite:dbname=([\w./]+),i;
         unlink $tmpfname;
-        my $schema = $db eq "ReportsDB" ? Tapper::Schema::ReportsDB->connect($dsn, $cfg->{username}, $cfg->{password}, { ignore_version => 1 })
-                                        : Tapper::Schema::TestrunDB->connect($dsn, $cfg->{username}, $cfg->{password}, { ignore_version => 1 });
+        my $schema = Tapper::Schema::TestrunDB->connect($dsn, $cfg->{username}, $cfg->{password}, { ignore_version => 1 });
         $schema->deploy;
-        $schema->upgrade if $schema->schema_version > $schema->get_db_version;
+#         $schema->upgrade if $schema->schema_version > $schema->get_db_version;
         return $schema;
 }
 
@@ -50,20 +41,13 @@ sub setup_testrundb {
 }
 
 
-sub setup_reportsdb {
-        $reportsdb_schema = setup_db("ReportsDB", Tapper::Config->subconfig->{test}{database});
-}
-
-
 sub import {
         my $pkg = caller(0);
         no strict 'refs';       ## no critic.
         *{"$pkg\::testrundb_schema"}  = sub () { $testrundb_schema };
-        *{"$pkg\::reportsdb_schema"}  = sub () { $reportsdb_schema };
 }
 
 setup_testrundb;
-setup_reportsdb;
 
 1;
 
@@ -71,7 +55,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -85,17 +69,23 @@ Setup and connect a test database using SQLite.
 
 Setup and connect a test TestrunDB using SQLite.
 
-=head2 setup_reportsdb
+=head1 AUTHORS
 
-Setup and connect a test ReportsDB using SQLite.
+=over 4
 
-=head1 AUTHOR
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
