@@ -1,7 +1,5 @@
 package Tapper::Schema::TestrunDB;
-BEGIN {
-  $Tapper::Schema::TestrunDB::AUTHORITY = 'cpan:TAPPER';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 
 use 5.010;
 
@@ -10,7 +8,7 @@ use warnings;
 
 # Only increment this version here on schema changes.
 # For everything else increment Tapper/Schema.pm.
-our $VERSION = '4.001004';
+our $VERSION = '4.001007';
 
 # avoid these warnings
 #   Subroutine initialize redefined at /2home/ss5/perl510/lib/site_perl/5.10.0/Class/C3.pm line 70.
@@ -19,16 +17,15 @@ our $VERSION = '4.001004';
 # by forcing correct load order.
 use Class::C3;
 use MRO::Compat;
-use YAML::Syck;
 
 use parent 'DBIx::Class::Schema';
 
 our $NULL  = 'NULL';
 our $DELIM = ' | ';
 
-__PACKAGE__->load_components(qw/+DBIx::Class::Schema::Versioned/);
-__PACKAGE__->upgrade_directory('./lib/auto/Tapper/Schema/');
-__PACKAGE__->backup_directory('./lib/auto/Tapper/Schema/');
+# __PACKAGE__->load_components(qw/+DBIx::Class::Schema::Versioned/);
+# __PACKAGE__->upgrade_directory('./lib/auto/Tapper/Schema/');
+# __PACKAGE__->backup_directory('./lib/auto/Tapper/Schema/');
 
 __PACKAGE__->load_namespaces;
 
@@ -43,9 +40,11 @@ sub backup
 sub _yaml_ok {
         my ($condition) = @_;
 
+        require YAML::Syck;
+
         my @res;
         eval {
-                @res = Load($condition);
+                @res = YAML::Syck::Load($condition);
         };
         return $@;
 }
@@ -56,7 +55,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -71,13 +70,23 @@ Check whether given string is valid yaml.
 @return success - undef
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
