@@ -1,17 +1,14 @@
 package Tapper::Schema::TestrunDB::Result::Owner;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::Owner::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::Owner::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::Owner::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Containg Tapper users
 
 use strict;
 use warnings;
 
 use parent 'DBIx::Class';
 
-__PACKAGE__->load_components("Core");
+__PACKAGE__->load_components(qw(Core));
 __PACKAGE__->table("owner");
 __PACKAGE__->add_columns
     (
@@ -21,7 +18,12 @@ __PACKAGE__->add_columns
      "password", { data_type => "VARCHAR", default_value => undef, is_nullable => 1, size => 255,                        },
     );
 
+(my $basepkg = __PACKAGE__) =~ s/::\w+$//;
+
 __PACKAGE__->set_primary_key("id");
+__PACKAGE__->add_unique_constraint( unique_login => [ qw/login/ ], );
+__PACKAGE__->has_many( contacts => "${basepkg}::Contact", { 'foreign.owner_id' => 'self.id' });
+__PACKAGE__->has_many( notifications => "${basepkg}::Notification", { 'foreign.owner_id' => 'self.id' });
 
 1;
 
@@ -29,43 +31,29 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::Owner
+Tapper::Schema::TestrunDB::Result::Owner - Tapper - Containg Tapper users
 
-=head1 SYNOPSIS
+=head1 AUTHORS
 
-Abstraction for the database table.
+=over 4
 
- use Tapper::Schema::TestrunDB;
-
-=head1 NAME
-
-Tapper::Schema::TestrunDB::Result::Owner - A ResultSet description
-
-=head1 AUTHOR
-
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
-
-=head1 BUGS
-
-None.
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
-
-This program is released under the following license: freebsd
-
-=head1 AUTHOR
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
