@@ -1,10 +1,7 @@
 package Tapper::Schema::TestrunDB::Result::Precondition;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::Precondition::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::Precondition::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::Precondition::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Containing Preconditions for Testruns
 
 use strict;
 use warnings;
@@ -101,14 +98,24 @@ sub update_content {
         my $yaml_error = Tapper::Schema::TestrunDB::_yaml_ok($condition);
         die Tapper::Exception::Param->new($yaml_error) if $yaml_error;
 
-        my $cond_hash = Load($condition);
+        my @a_conditions = Load($condition);
+        if ( scalar @a_conditions > 1 ) {
+            say {*STDERR} 'cannot update a single precondition with a set of preconditions';
+            return;
+        }
 
+        my $cond_hash = $a_conditions[0];
         $self->shortname( $cond_hash->{shortname} ) if $cond_hash->{shortname};
         $self->precondition( $condition );
         $self->timeout( $cond_hash->{timeout} ) if $cond_hash->{timeout};
-        $self->update;
 
-        return $self->id;
+        if ( $self->update ) {
+            return $self->id;
+        }
+        else {
+            say {*STDERR} 'update precondition failed: ' . $self->id;
+            return;
+        }
 }
 
 1;
@@ -117,11 +124,11 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::Precondition
+Tapper::Schema::TestrunDB::Result::Precondition - Tapper - Containing Preconditions for Testruns
 
 =head2 one_line
 
@@ -147,13 +154,23 @@ Provide the precondition YAML as actual data structure.
 
 Update precondition from given params.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
