@@ -1,10 +1,7 @@
 package Tapper::Schema::TestrunDB::Result::Scenario;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::Scenario::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::Scenario::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::Scenario::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Grouping of interdependent tests
 
 use 5.010;
 use strict;
@@ -18,10 +15,26 @@ __PACKAGE__->add_columns
     (
      "id",   { data_type => "INT",       default_value => undef, is_nullable => 0, size => 11,  is_auto_increment => 1, },
      "type", { data_type => "VARCHAR",   default_value => "",    is_nullable => 0, size => 255,                         },
+     "options", { data_type => "TEXT",    default       => undef, is_nullable => 1,                                      },
+     "name",  { data_type => "VARCHAR",                           is_nullable => 1,                                      },
     );
 
 __PACKAGE__->set_primary_key(qw/id/);
 
+__PACKAGE__->inflate_column(
+    options => {
+        inflate => sub {
+            require YAML::XS;
+            YAML::XS::Load(shift);
+        },
+        deflate => sub {
+            require YAML::XS;
+            YAML::XS::Dump(shift);
+        },
+    }
+);
+
+
 (my $basepkg = __PACKAGE__) =~ s/::\w+$//;
 
 __PACKAGE__->has_many  ( scenario_elements => "${basepkg}::ScenarioElement", { 'foreign.scenario_id'   => 'self.id' });
@@ -33,43 +46,29 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::Scenario
+Tapper::Schema::TestrunDB::Result::Scenario - Tapper - Grouping of interdependent tests
 
-=head1 SYNOPSIS
+=head1 AUTHORS
 
-Abstraction for the database table.
+=over 4
 
- use Tapper::Schema::TestrunDB;
-
-=head1 NAME
-
-Tapper::Schema::TestrunDB::Result::Testgroup - Grouping of interdependent tests
-
-=head1 AUTHOR
-
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
-
-=head1 BUGS
-
-None.
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
-
-This program is released under the following license: freebsd
-
-=head1 AUTHOR
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
