@@ -1,10 +1,7 @@
 package Tapper::Schema::TestrunDB::Result::ScenarioElement;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::ScenarioElement::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::ScenarioElement::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::ScenarioElement::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Containing relations between scenarios and testrun_ids
 
 use 5.010;
 use strict;
@@ -34,6 +31,7 @@ __PACKAGE__->has_many  ( peer_elements => "${basepkg}::ScenarioElement", { 'fore
 sub peers_need_fitting
 {
         my ($self) = @_;
+        return 0 if $self->scenario->type ne 'interdep';
         return $self->peer_elements->search({is_fitted => { '!=' => 1,}})->count;
 }
 
@@ -43,11 +41,11 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::ScenarioElement
+Tapper::Schema::TestrunDB::Result::ScenarioElement - Tapper - Containing relations between scenarios and testrun_ids
 
 =head2 peers_need_fitting
 
@@ -56,13 +54,23 @@ set. This count may include $self.
 
 @return int - number of unfitted elements in same scenario
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
