@@ -1,10 +1,7 @@
 package Tapper::Schema::TestrunDB::Result::State;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::State::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::State::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::State::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Containg states for testrun's
 
 use strict;
 use warnings;
@@ -33,50 +30,35 @@ __PACKAGE__->set_primary_key("id");
 __PACKAGE__->add_unique_constraint( unique_testrun_id => [ qw/testrun_id/ ], );
 __PACKAGE__->belongs_to( testrun => "${basepkg}::Testrun", { 'foreign.id' => 'self.testrun_id' });
 
-
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::State
+Tapper::Schema::TestrunDB::Result::State - Tapper - Containg states for testrun's
 
-=head1 SYNOPSIS
+=head1 AUTHORS
 
-Abstraction for the database table.
+=over 4
 
- use Tapper::Schema::TestrunDB;
-
-=head1 NAME
-
-Tapper::Schema::TestrunDB::Result::State - A ResultSet description
-
-=head1 AUTHOR
-
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
-
-=head1 BUGS
-
-None.
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
-
-This program is released under the following license: freebsd
-
-=head1 AUTHOR
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
