@@ -1,53 +1,170 @@
 package Tapper::Schema::TestrunDB::Result::Testrun;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::Testrun::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::Testrun::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::Testrun::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Containing Testruns
 
 use 5.010;
 use strict;
 use warnings;
 
 use parent 'DBIx::Class';
-use Data::Dumper;
 
 __PACKAGE__->load_components(qw/InflateColumn::DateTime Core/);
-__PACKAGE__->table("testrun");
-__PACKAGE__->add_columns
-    (
-     "id",                        { data_type => "INT",       default_value => undef, is_nullable => 0, size => 11,    is_auto_increment => 1, },
-     "shortname",                 { data_type => "VARCHAR",   default_value => "",    is_nullable => 1, size => 255,                           },
-     "notes",                     { data_type => "TEXT",      default_value => "",    is_nullable => 1,                                        },
-     "topic_name",                { data_type => "VARCHAR",   default_value => "",    is_nullable => 0, size => 255,    is_foreign_key => 1,    },
-     "starttime_earliest",        { data_type => "DATETIME",  default_value => undef, is_nullable => 1,                                        },
-     "starttime_testrun",         { data_type => "DATETIME",  default_value => undef, is_nullable => 1,                                        },
-     "starttime_test_program",    { data_type => "DATETIME",  default_value => undef, is_nullable => 1,                                        },
-     "endtime_test_program",      { data_type => "DATETIME",  default_value => undef, is_nullable => 1,                                        },
-     "owner_id",                  { data_type => "INT",       default_value => undef, is_nullable => 1, size => 11,    is_foreign_key => 1,    },
-     "testplan_id",               { data_type => "INT",       default_value => undef, is_nullable => 1, size => 11,    is_foreign_key => 1,    },
-     "wait_after_tests",          { data_type => "INT",       default_value => 0,     is_nullable => 1, size => 1,                             },
-     "rerun_on_error",            { data_type => "INT",       default_value => 0,     is_nullable => 1, size => 11,                            }, # number of times to rerun this test on error
-     "created_at" ,               { data_type => "TIMESTAMP", default_value => \'CURRENT_TIMESTAMP',  is_nullable => 0, set_on_create => 1,                     },
-     "updated_at",                { data_type => "DATETIME", default_value => undef,  is_nullable => 1, set_on_create => 1, set_on_update => 1, },
-    );
+__PACKAGE__->table('testrun');
+__PACKAGE__->add_columns(
+    'id', {
+        data_type           => 'INT',
+        default_value       => undef,
+        is_nullable         => 0,
+        size                => 11,
+        is_auto_increment   => 1,
+        extra               => {
+            unsigned => 1,
+        },
+    },
+    'shortname', {
+        data_type           => 'VARCHAR',
+        default_value       => undef,
+        is_nullable         => 0,
+        size                => 255,
+    },
+    'notes', {
+        data_type           => 'TEXT',
+        default_value       => undef,
+        is_nullable         => 1,
+    },
+    'topic_name', {
+        data_type           => 'VARCHAR',
+        default_value       => undef,
+        is_nullable         => 0,
+        size                => 255,
+        is_foreign_key      => 1,
+    },
+    'starttime_earliest', {
+        data_type           => 'TIMESTAMP',
+        default_value       => undef,
+        is_nullable         => 1,
+    },
+    'starttime_testrun', {
+        data_type           => 'TIMESTAMP',
+        default_value       => undef,
+        is_nullable         => 1,
+    },
+    'starttime_test_program', {
+        data_type           => 'TIMESTAMP',
+        default_value       => undef,
+        is_nullable         => 1,
+    },
+    'endtime_test_program', {
+        data_type           => 'TIMESTAMP',
+        default_value       => undef,
+        is_nullable         => 1,
+    },
+    'owner_id', {
+        data_type           => 'SMALLINT',
+        default_value       => undef,
+        is_nullable         => 1,
+        size                => 6,
+        is_foreign_key      => 1,
+        extra               => {
+            unsigned => 1,
+        },
+    },
+    'testplan_id', {
+        data_type           => 'INT',
+        default_value       => undef,
+        is_nullable         => 1,
+        size                => 11,
+        is_foreign_key      => 1,
+        extra               => {
+            unsigned => 1,
+        },
+    },
+    'wait_after_tests', {
+        data_type           => 'TINYINT',
+        default_value       => 0,
+        is_nullable         => 1,           #TODO: 0
+        size                => 1,
+        extra               => {
+            unsigned => 1,
+        },
+    },
+    # number of times to rerun this test on error
+    'rerun_on_error', {
+        data_type           => 'TINYINT',
+        default_value       => 0,
+        is_nullable         => 1,           #TODO: 0
+        size                => 1,
+        extra               => {
+            unsigned => 1,
+        },
+    },
+    'created_at', {
+        data_type           => 'TIMESTAMP',
+        default_value       => undef,
+        is_nullable         => 1,
+        set_on_create       => 1,
+    },
+    'updated_at', {
+        data_type           => 'TIMESTAMP',
+        default_value       => undef,
+        is_nullable         => 1,
+        set_on_create       => 1,
+        set_on_update       => 1,
+    },
+);
 
-__PACKAGE__->set_primary_key("id");
+__PACKAGE__->set_primary_key('id');
 
 (my $basepkg = __PACKAGE__) =~ s/::\w+$//;
 
-__PACKAGE__->belongs_to   ( owner                      => "${basepkg}::Owner",                   { 'foreign.id'   => 'self.owner_id' });
-__PACKAGE__->belongs_to   ( testplan_instance          => "${basepkg}::TestplanInstance",        { 'foreign.id'   => 'self.testplan_id'   });
+# * : 1
+__PACKAGE__->belongs_to(
+    owner                   => "${basepkg}::Owner",
+    { 'foreign.id'          => 'self.owner_id' },
+);
+__PACKAGE__->belongs_to(
+    testplan_instance       => "${basepkg}::TestplanInstance",
+    { 'foreign.id'          => 'self.testplan_id' },
+);
 
-__PACKAGE__->has_many     ( testrun_precondition       => "${basepkg}::TestrunPrecondition",     { 'foreign.testrun_id' => 'self.id' });
-__PACKAGE__->many_to_many ( preconditions              => "testrun_precondition",                                        'precondition' );
+# 1 : 0,1
+__PACKAGE__->might_have(
+    testrun_scheduling      => "${basepkg}::TestrunScheduling",
+    { 'foreign.testrun_id'  => 'self.id' },
+);
+__PACKAGE__->might_have(
+    scenario_element        => "${basepkg}::ScenarioElement",
+    { 'foreign.testrun_id'  => 'self.id' },
+);
+__PACKAGE__->might_have(
+    state                   => "${basepkg}::State",
+    { 'foreign.testrun_id'  => 'self.id' },
+);
+__PACKAGE__->might_have(
+    reportgrouptestrunstats => "${basepkg}::ReportgroupTestrunStats",
+    { 'foreign.testrun_id'  => 'self.id' },
+);
 
-__PACKAGE__->might_have   ( testrun_scheduling         => "${basepkg}::TestrunScheduling",       { 'foreign.testrun_id' => 'self.id' });
-__PACKAGE__->might_have   ( scenario_element           => "${basepkg}::ScenarioElement",         { 'foreign.testrun_id' => 'self.id' });
-__PACKAGE__->might_have   ( state                      => "${basepkg}::State",                   { 'foreign.testrun_id' => 'self.id' });
-__PACKAGE__->has_many     ( message                    => "${basepkg}::Message",                 { 'foreign.testrun_id' => 'self.id' });
+# 1 : *
+__PACKAGE__->has_many(
+    testrun_precondition    => "${basepkg}::TestrunPrecondition",
+    { 'foreign.testrun_id'  => 'self.id' },
+);
+__PACKAGE__->has_many(
+    message                 => "${basepkg}::Message",
+    { 'foreign.testrun_id'  => 'self.id' },
+);
+__PACKAGE__->has_many(
+    testrun_requested_host  => "${basepkg}::TestrunRequestedHost",
+    { 'foreign.testrun_id'  => 'self.id' },
+);
 
+# * : *
+__PACKAGE__->many_to_many(
+    preconditions           => "testrun_precondition",
+    'precondition'
+);
 
 # -------------------- methods on results --------------------
 
@@ -181,7 +298,9 @@ sub rerun
         $testrunscheduling_new->status('schedule');
         $testrunscheduling_new->update;
         $testrun_new->assign_preconditions(@preconditions);
-        return $testrun_new->id;
+
+        return $testrun_new;
+
 }
 
 
@@ -270,11 +389,11 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::Testrun
+Tapper::Schema::TestrunDB::Result::Testrun - Tapper - Containing Testruns
 
 =head2 to_string
 
@@ -308,6 +427,8 @@ from $self.
 
 Assign given preconditions to this testrun.
 
+@param  array   - list of precondition ids
+
 @return success - 0
 @return error   - error message
 
@@ -326,17 +447,29 @@ all later preconditions to make sure they come after the inserted.
 
 Disconnect list of preconditions from a testrun.
 
+@param array - list of precondition ids
+
 =head2 sqlt_deploy_hook
 
 Add useful indexes at deploy time.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
