@@ -1,10 +1,7 @@
 package Tapper::Schema::TestrunDB::Result::TestrunRequestedFeature;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::TestrunRequestedFeature::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::TestrunRequestedFeature::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::TestrunRequestedFeature::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Relate features and testruns
 
 use strict;
 use warnings;
@@ -30,43 +27,29 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::TestrunRequestedFeature
+Tapper::Schema::TestrunDB::Result::TestrunRequestedFeature - Tapper - Relate features and testruns
 
-=head1 SYNOPSIS
+=head1 AUTHORS
 
-Abstraction for the database table.
+=over 4
 
- use Tapper::Schema::TestrunDB;
-
-=head1 NAME
-
-Tapper::Schema::TestrunDB::Result::PrePrecondition - A ResultSet description
-
-=head1 AUTHOR
-
-AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
-
-=head1 BUGS
-
-None.
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
-
-This program is released under the following license: freebsd
-
-=head1 AUTHOR
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
