@@ -1,12 +1,9 @@
 # TODO: rename into "(Scheduler|Result)::Job"?
 
 package Tapper::Schema::TestrunDB::Result::TestrunScheduling;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::TestrunScheduling::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::TestrunScheduling::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::TestrunScheduling::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Containing informations for an executed testrun
 
 use YAML::Syck;
 use common::sense;
@@ -48,12 +45,23 @@ sub mark_as_running
 
         # set scheduling info
         $self->status("running");
-        $self->host->free(0);
+        # need a transaction because someone might access this
+        # variable on the CLI
+        my $guard = $self->result_source->schema->txn_scope_guard;
+
+        if ($self->host->is_pool) {
+                $self->host->get_from_storage;
+                $self->host->pool_free($self->host->pool_free-1);
+                $self->host->free(0) if $self->host->pool_free == 0;
+        } else {
+                $self->host->free(0);
+        }
         $self->prioqueue_seq(undef);
 
         # sync db
         $self->host->update;
         $self->update;
+        $guard->commit;
 }
 
 
@@ -61,15 +69,27 @@ sub mark_as_finished
 {
         my ($self) = @_;
 
-        use Data::Dumper;
-
         # set scheduling info
         $self->status("finished");
-        $self->host->free(1);
+
+        # need a transaction because someone might access this
+        # variable on the CLI
+        my $guard = $self->result_source->schema->txn_scope_guard;
+
+        if ($self->host->is_pool) {
+                $self->host($self->host->get_from_storage);
+                $self->host->pool_free($self->host->pool_free+1);
+                if ($self->host->pool_free > 0) {
+                        $self->host->free(1);
+                }
+        } else {
+                $self->host->free(1);
+        }
 
         # sync db
         $self->host->update;
         $self->update;
+        $guard->commit;
 }
 
 
@@ -86,11 +106,11 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::TestrunScheduling
+Tapper::Schema::TestrunDB::Result::TestrunScheduling - Tapper - Containing informations for an executed testrun
 
 =head2 mark_as_running
 
@@ -104,13 +124,23 @@ Mark a testrun as I<finished>.
 
 Add useful indexes at deploy time.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
