@@ -1,10 +1,7 @@
 package Tapper::Schema::TestrunDB::Result::Topic;
-BEGIN {
-  $Tapper::Schema::TestrunDB::Result::Topic::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::Result::Topic::VERSION = '4.1.3';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::Result::Topic::VERSION = '5.0.0';
+# ABSTRACT: Tapper - Containg topic informations
 
 use strict;
 use warnings;
@@ -40,11 +37,11 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::Topic
+Tapper::Schema::TestrunDB::Result::Topic - Tapper - Containg topic informations
 
 =head1 SYNOPSIS
 
@@ -70,13 +67,23 @@ Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
