@@ -1,16 +1,10 @@
 package Tapper::Schema::TestrunDB::ResultSet::Precondition;
-BEGIN {
-  $Tapper::Schema::TestrunDB::ResultSet::Precondition::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::ResultSet::Precondition::VERSION = '4.1.3';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::ResultSet::Precondition::VERSION = '5.0.0';
 use strict;
 use warnings;
 
 use parent 'DBIx::Class::ResultSet';
-use YAML::Syck;
 
 
 sub add {
@@ -19,6 +13,7 @@ sub add {
         my @precond_list = @$preconditions;
         my @precond_ids;
 
+        require YAML::Syck;
         foreach my $precond_data (@precond_list) {
                 # (XXX) decide how to handle empty preconditions
                 next if not (ref($precond_data) eq 'HASH');
@@ -27,7 +22,7 @@ sub add {
                 my $precondition = $self->result_source->schema->resultset('Precondition')->new
                     ({
                       shortname    => $shortname,
-                      precondition => Dump($precond_data),
+                      precondition => YAML::Syck::Dump($precond_data),
                       timeout      => $timeout,
                      });
                 $precondition->insert;
@@ -42,7 +37,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -53,13 +48,23 @@ Tapper::Schema::TestrunDB::ResultSet::Precondition
 Create (add) a list of preconditions and return them with their now
 associated db data (eg. ID).
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
