@@ -1,11 +1,6 @@
 package Tapper::Schema::TestrunDB::ResultSet::Queue;
-BEGIN {
-  $Tapper::Schema::TestrunDB::ResultSet::Queue::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::ResultSet::Queue::VERSION = '4.1.3';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::ResultSet::Queue::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -19,19 +14,29 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 Tapper::Schema::TestrunDB::ResultSet::Queue
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
