@@ -1,17 +1,9 @@
 package Tapper::Schema::TestrunDB::ResultSet::Testrun;
-BEGIN {
-  $Tapper::Schema::TestrunDB::ResultSet::Testrun::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::ResultSet::Testrun::VERSION = '4.1.3';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::ResultSet::Testrun::VERSION = '5.0.0';
 use strict;
 use warnings;
 
-use DateTime;
-
-
 use parent 'DBIx::Class::ResultSet';
 
 
@@ -47,6 +39,7 @@ sub due_testruns
 {
         my ($self) = @_;
 
+        require DateTime;
         my $now = $self->result_source->storage->datetime_parser->format_datetime(DateTime->now);
         return $self->search(
                              {
@@ -82,6 +75,7 @@ sub add {
               starttime_earliest    => $args->{earliest},
               owner_id              => $args->{owner_id},
               rerun_on_error        => $args->{rerun_on_error},
+              wait_after_tests      => $args->{wait_after_tests},
              });
 
         $testrun->insert;
@@ -92,7 +86,7 @@ sub add {
               testrun_id => $testrun->id,
               queue_id   => $args->{queue_id},
               host_id    => $args->{host_id},
-              status     => "schedule",
+              status     => $args->{status} || "schedule",
               auto_rerun => $args->{auto_rerun} || 0,
              });
         if ($args->{priority}) {
@@ -128,7 +122,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -163,13 +157,23 @@ Search for testrun with given status.
 Insert (add) a new testrun into DB, assign it with other typical also
 inserted db rows, and return it.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
