@@ -1,11 +1,6 @@
 package Tapper::Schema::TestrunDB::ResultSet::TestrunScheduling;
-BEGIN {
-  $Tapper::Schema::TestrunDB::ResultSet::TestrunScheduling::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Schema::TestrunDB::ResultSet::TestrunScheduling::VERSION = '4.1.3';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Schema::TestrunDB::ResultSet::TestrunScheduling::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -52,7 +47,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -76,13 +71,23 @@ Get all running jobs.
 
 @return __PACKAGE__ object
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
